==> tine20-voip_2019.12.5.tar.bz2: Phone/js/Phone-lang-hu-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Hungarian (http://www.transifex.com/tine20/tine20/language/hu/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: hu\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Call"
: ""

, "Calls"
: ""

, "Line"
: "Vonal"

, "Caller Id"
: "Hívó azonosító"

, "Start"
: "Kezdés"

, "Connected"
: "Kapcsolódva"

, "Disconnected"
: "Kapcsolat bontva"

, "Duration"
: "Időtartam"

, "Ringing"
: "Csörgés"

, "Direction"
: "Irány"

, "Source"
: "Forrás"

, "Destination"
: "Cél"

, "Phone"
: ""

, "Phones"
: "Telefonok"

, "Settings"
: ""

, "Lines"
: ""

, "Description"
: ""

, "Number"
: "Szám"

, "Cancel"
: "Mégse"

, "Dial"
: "Tárcsázás"

, "Error"
: "Hiba"

, "Not possible to dial."
: "Nem lehetséges tárcsázni."

, "Edit phone settings"
: "Telefon beállítások szerkesztése"

, "Dial number"
: "Szám tárcsázása"

, "Initiate a new outgoing call"
: "Új kimenő hívás letesítése"

, "No phone selected"
: ""

, "Please select the desired phone in the tree!"
: ""

, "Call contact"
: "Kapcsolat hívása"

, "Work"
: "Munkahelyi"

, "Home"
: "Otthoni"

, "Cell"
: "Mobil"

, "Cell private"
: "Mobil privát"

, "Incoming call"
: "Bejövő hívás"

, "Outgoing call"
: "Kimenő hívás"

, "unknown number"
: "ismeretlen szám"

, "local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "identifies if a calling number is a local call without leading area code"
: ""

, "own telephone number"
: ""

, "own telephone number to prefix to internal calls"
: ""

, "Calls this week"
: ""

, "Incoming and outgoing calls of this week"
: ""

, "Calls last week"
: ""

, "Incoming and outgoing calls of last week"
: ""

, "Calls this month"
: ""

, "Incoming and outgoing calls of this month"
: ""

, "Calls last month"
: ""

, "Incoming and outgoing calls of last month"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-voip_2020.08.8.tar.bz2: Phone/js/Phone-lang-hu-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Hungarian (http://www.transifex.com/tine20/tine20/language/hu/)\nLanguage: hu\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Incoming call"
: "Bejövő hívás"

, "Outgoing call"
: "Kimenő hívás"

, "unknown number"
: "ismeretlen szám"

, "Phone"
: ""

, "Line"
: "Vonal"

, "Number"
: "Szám"

, "Cancel"
: "Mégse"

, "Dial"
: "Tárcsázás"

, "Error"
: "Hiba"

, "Not possible to dial."
: "Nem lehetséges tárcsázni."

, "Call contact"
: "Kapcsolat hívása"

, "Work"
: "Munkahelyi"

, "Home"
: "Otthoni"

, "Cell"
: "Mobil"

, "Cell private"
: "Mobil privát"

, "Edit phone settings"
: "Telefon beállítások szerkesztése"

, "Dial number"
: "Szám tárcsázása"

, "Initiate a new outgoing call"
: "Új kimenő hívás letesítése"

, "Phones"
: "Telefonok"

, "No phone selected"
: ""

, "Please select the desired phone in the tree!"
: ""

, "Calls this week"
: ""

, "Calls last week"
: ""

, "Calls this month"
: ""

, "Calls last month"
: ""

, "Incoming and outgoing calls of this week"
: ""

, "Incoming and outgoing calls of last week"
: ""

, "Incoming and outgoing calls of this month"
: ""

, "Incoming and outgoing calls of last month"
: ""

, "Local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "Identifies if a calling number is a local call without leading area code."
: ""

, "own telephone number"
: ""

, "Own telephone number to prefix to internal calls."
: ""

, "Call"
: ""

, "Calls"
: ""

, "Caller Id"
: "Hívó azonosító"

, "Start"
: "Kezdés"

, "Connected"
: "Kapcsolódva"

, "Disconnected"
: "Kapcsolat bontva"

, "Duration"
: "Időtartam"

, "Ringing"
: "Csörgés"

, "Direction"
: "Irány"

, "Source"
: "Forrás"

, "Destination"
: "Cél"

, "resolved destination"
: ""

, "Settings"
: ""

, "Lines"
: ""

, "Description"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
